summaryrefslogtreecommitdiff
path: root/sc
diff options
context:
space:
mode:
authorCaolán McNamara <caolanm@redhat.com>2013-10-20 15:15:42 +0100
committerCaolán McNamara <caolanm@redhat.com>2013-10-20 19:00:36 +0100
commit45e366eadbba69140214a8e745a1d3ce3e4e8337 (patch)
treecf01cfc9006789d7effb61ae140028829fc879c6 /sc
parent8bb4b18127cdc6259ecd65ec0f28d27d0513cb26 (diff)
drop unnecessary tools/string includes
Change-Id: I4278999b9b7d184c26036bbe9e3b98420f461e8c
Diffstat (limited to 'sc')
-rw-r--r--sc/inc/address.hxx1
-rw-r--r--sc/inc/chartuno.hxx1
-rw-r--r--sc/inc/docpool.hxx2
-rw-r--r--sc/inc/document.hxx8
-rw-r--r--sc/inc/dpdimsave.hxx1
-rw-r--r--sc/inc/dptabres.hxx1
-rw-r--r--sc/inc/dptabsrc.hxx1
-rw-r--r--sc/inc/filter.hxx17
-rw-r--r--sc/inc/global.hxx4
-rw-r--r--sc/inc/lookupcache.hxx1
-rw-r--r--sc/inc/patattr.hxx1
-rw-r--r--sc/inc/pch/precompiled_sc.hxx1
-rw-r--r--sc/inc/pch/precompiled_vbaobj.hxx1
-rw-r--r--sc/inc/progress.hxx2
-rw-r--r--sc/inc/rangeutl.hxx2
-rw-r--r--sc/inc/scabstdlg.hxx1
-rw-r--r--sc/inc/stringutil.hxx5
-rw-r--r--sc/inc/targuno.hxx1
-rw-r--r--sc/inc/userlist.hxx1
-rw-r--r--sc/inc/zforauto.hxx6
-rw-r--r--sc/source/core/data/documen8.cxx1
-rw-r--r--sc/source/core/inc/interpre.hxx1
-rw-r--r--sc/source/core/tool/zforauto.cxx4
-rw-r--r--sc/source/filter/dif/difexp.cxx6
-rw-r--r--sc/source/filter/dif/difimp.cxx6
-rw-r--r--sc/source/filter/excel/xistream.cxx2
-rw-r--r--sc/source/filter/inc/dif.hxx12
-rw-r--r--sc/source/filter/inc/eeparser.hxx1
-rw-r--r--sc/source/filter/inc/excscen.hxx3
-rw-r--r--sc/source/filter/inc/exp_op.hxx4
-rw-r--r--sc/source/filter/inc/ftools.hxx15
-rw-r--r--sc/source/filter/inc/lotfntbf.hxx1
-rw-r--r--sc/source/filter/inc/root.hxx4
-rw-r--r--sc/source/filter/inc/xestyle.hxx1
-rw-r--r--sc/source/filter/rtf/rtfexp.cxx2
-rw-r--r--sc/source/ui/docshell/impex.cxx10
-rw-r--r--sc/source/ui/inc/AccessibleCsvControl.hxx1
-rw-r--r--sc/source/ui/inc/asciiopt.hxx1
-rw-r--r--sc/source/ui/inc/autostyl.hxx4
-rw-r--r--sc/source/ui/inc/gridwin.hxx1
-rw-r--r--sc/source/ui/inc/lnktrans.hxx2
-rw-r--r--sc/source/ui/unoobj/pageuno.cxx2
-rw-r--r--sc/source/ui/vba/vbaworksheet.cxx2
-rw-r--r--sc/source/ui/vba/vbaworksheets.cxx1
-rw-r--r--sc/workben/result.hxx2
45 files changed, 61 insertions, 86 deletions
diff --git a/sc/inc/address.hxx b/sc/inc/address.hxx
index 7fcd1f01a476..f764e083e626 100644
--- a/sc/inc/address.hxx
+++ b/sc/inc/address.hxx
@@ -21,7 +21,6 @@
#define SC_ADDRESS_HXX
#include <tools/stream.hxx>
-#include <tools/string.hxx>
#include <tools/solar.h>
#include <rtl/ustrbuf.hxx>
#include <osl/endian.h>
diff --git a/sc/inc/chartuno.hxx b/sc/inc/chartuno.hxx
index 45c74216c865..3094b64ee258 100644
--- a/sc/inc/chartuno.hxx
+++ b/sc/inc/chartuno.hxx
@@ -22,7 +22,6 @@
#include "address.hxx"
#include <svl/lstner.hxx>
-#include <tools/string.hxx>
#include <comphelper/proparrhlp.hxx>
#include <comphelper/propertycontainer.hxx>
diff --git a/sc/inc/docpool.hxx b/sc/inc/docpool.hxx
index c794148e79ce..cacc9ee7ae2f 100644
--- a/sc/inc/docpool.hxx
+++ b/sc/inc/docpool.hxx
@@ -20,8 +20,8 @@
#ifndef SC_SCDOCPOL_HXX
#define SC_SCDOCPOL_HXX
+#include <rtl/ustring.hxx>
#include <svl/itempool.hxx>
-#include <tools/string.hxx>
#include "scdllapi.h"
class ScStyleSheet;
diff --git a/sc/inc/document.hxx b/sc/inc/document.hxx
index f7df5f619686..20222fa2130a 100644
--- a/sc/inc/document.hxx
+++ b/sc/inc/document.hxx
@@ -340,7 +340,7 @@ private:
LanguageType eLanguage; // default language
LanguageType eCjkLanguage; // default language for asian text
LanguageType eCtlLanguage; // default language for complex text
- CharSet eSrcSet; // during reading: source character set
+ rtl_TextEncoding eSrcSet; // during reading: source character set
/** The compiler grammar used in document storage. GRAM_PODF for ODF 1.1
documents, GRAM_ODFF for ODF 1.2 documents. */
@@ -1597,11 +1597,11 @@ public:
SC_DLLPUBLIC void CopyStdStylesFrom( ScDocument* pSrcDoc );
- CharSet GetSrcCharSet() const { return eSrcSet; }
+ rtl_TextEncoding GetSrcCharSet() const { return eSrcSet; }
sal_uLong GetSrcVersion() const { return nSrcVer; }
SCROW GetSrcMaxRow() const { return nSrcMaxRow; }
- void SetSrcCharSet( CharSet eNew ) { eSrcSet = eNew; }
+ void SetSrcCharSet( rtl_TextEncoding eNew ) { eSrcSet = eNew; }
void UpdateFontCharSet();
void FillInfo(
@@ -1915,7 +1915,7 @@ public:
points times sizeof(sal_Unicode) is returned. */
sal_Int32 GetMaxStringLen( SCTAB nTab, SCCOL nCol,
SCROW nRowStart, SCROW nRowEnd,
- CharSet eCharSet ) const;
+ rtl_TextEncoding eCharSet ) const;
/** Maximum string length of numerical cells of a column, e.g. for dBase export.
@return String length in characters (!) including the decimal
separator, and the decimal precision needed. */
diff --git a/sc/inc/dpdimsave.hxx b/sc/inc/dpdimsave.hxx
index 13d9faa2fca0..375e76a2472d 100644
--- a/sc/inc/dpdimsave.hxx
+++ b/sc/inc/dpdimsave.hxx
@@ -22,7 +22,6 @@
#include <vector>
#include <map>
-#include <tools/string.hxx>
#include "dpgroup.hxx" ///< for ScDPNumGroupInfo
#include "scdllapi.h"
#include "dptypes.hxx"
diff --git a/sc/inc/dptabres.hxx b/sc/inc/dptabres.hxx
index 4017fe119332..4610f20348d0 100644
--- a/sc/inc/dptabres.hxx
+++ b/sc/inc/dptabres.hxx
@@ -24,7 +24,6 @@
#include "dpfilteredcache.hxx"
#include "calcmacros.hxx"
-#include <tools/string.hxx>
#include <com/sun/star/sheet/MemberResult.hpp>
#include <com/sun/star/sheet/DataResult.hpp>
#include <com/sun/star/uno/Sequence.hxx>
diff --git a/sc/inc/dptabsrc.hxx b/sc/inc/dptabsrc.hxx
index 60f92121f930..b2d7a4146cf2 100644
--- a/sc/inc/dptabsrc.hxx
+++ b/sc/inc/dptabsrc.hxx
@@ -20,7 +20,6 @@
#ifndef SC_DPTABSRC_HXX
#define SC_DPTABSRC_HXX
-#include <tools/string.hxx>
#include "global.hxx" // enum ScSubTotalFunc
#include <com/sun/star/sheet/XDimensionsSupplier.hpp>
#include <com/sun/star/sheet/XHierarchiesSupplier.hpp>
diff --git a/sc/inc/filter.hxx b/sc/inc/filter.hxx
index 6f6607322bd9..2a3b9f59a642 100644
--- a/sc/inc/filter.hxx
+++ b/sc/inc/filter.hxx
@@ -20,8 +20,9 @@
#ifndef SC_FILTER_HXX
#define SC_FILTER_HXX
-#include <tools/string.hxx>
#include <rtl/textenc.h>
+#include <rtl/ustring.hxx>
+#include <tools/solar.h>
#include "scdllapi.h"
@@ -84,7 +85,7 @@ class ScEEAbsImport {
class ScFormatFilterPlugin {
public:
// various import filters
- virtual FltError ScImportLotus123( SfxMedium&, ScDocument*, CharSet eSrc = RTL_TEXTENCODING_DONTKNOW ) = 0;
+ virtual FltError ScImportLotus123( SfxMedium&, ScDocument*, rtl_TextEncoding eSrc = RTL_TEXTENCODING_DONTKNOW ) = 0;
virtual FltError ScImportQuattroPro( SfxMedium &rMedium, ScDocument *pDoc ) = 0;
virtual FltError ScImportExcel( SfxMedium&, ScDocument*, const EXCIMPFORMAT ) = 0;
// eFormat == EIF_AUTO -> matching filter is used automatically
@@ -93,7 +94,7 @@ class ScFormatFilterPlugin {
// eFormat == EIF_BIFF_LE4 -> only non storage files _might_ be read successfully
virtual FltError ScImportStarCalc10( SvStream&, ScDocument* ) = 0;
virtual FltError ScImportDif( SvStream&, ScDocument*, const ScAddress& rInsPos,
- const CharSet eSrc = RTL_TEXTENCODING_DONTKNOW, sal_uInt32 nDifOption = SC_DIFOPT_EXCEL ) = 0;
+ const rtl_TextEncoding eSrc = RTL_TEXTENCODING_DONTKNOW, sal_uInt32 nDifOption = SC_DIFOPT_EXCEL ) = 0;
virtual FltError ScImportRTF( SvStream&, const OUString& rBaseURL, ScDocument*, ScRange& rRange ) = 0;
virtual FltError ScImportHTML( SvStream&, const OUString& rBaseURL, ScDocument*, ScRange& rRange, double nOutputFactor = 1.0,
bool bCalcWidthHeight = true, SvNumberFormatter* pFormatter = NULL, bool bConvertDate = true ) = 0;
@@ -104,14 +105,14 @@ class ScFormatFilterPlugin {
virtual OUString GetHTMLRangeNameList( ScDocument* pDoc, const OUString& rOrigName ) = 0;
// various export filters
- virtual FltError ScExportExcel5( SfxMedium&, ScDocument*, ExportFormatExcel eFormat, CharSet eDest ) = 0;
- virtual FltError ScExportDif( SvStream&, ScDocument*, const ScAddress& rOutPos, const CharSet eDest,
+ virtual FltError ScExportExcel5( SfxMedium&, ScDocument*, ExportFormatExcel eFormat, rtl_TextEncoding eDest ) = 0;
+ virtual FltError ScExportDif( SvStream&, ScDocument*, const ScAddress& rOutPos, const rtl_TextEncoding eDest,
sal_uInt32 nDifOption = SC_DIFOPT_EXCEL ) = 0;
- virtual FltError ScExportDif( SvStream&, ScDocument*, const ScRange& rRange, const CharSet eDest,
+ virtual FltError ScExportDif( SvStream&, ScDocument*, const ScRange& rRange, const rtl_TextEncoding eDest,
sal_uInt32 nDifOption = SC_DIFOPT_EXCEL ) = 0;
- virtual FltError ScExportHTML( SvStream&, const OUString& rBaseURL, ScDocument*, const ScRange& rRange, const CharSet eDest, bool bAll,
+ virtual FltError ScExportHTML( SvStream&, const OUString& rBaseURL, ScDocument*, const ScRange& rRange, const rtl_TextEncoding eDest, bool bAll,
const OUString& rStreamPath, OUString& rNonConvertibleChars ) = 0;
- virtual FltError ScExportRTF( SvStream&, ScDocument*, const ScRange& rRange, const CharSet eDest ) = 0;
+ virtual FltError ScExportRTF( SvStream&, ScDocument*, const ScRange& rRange, const rtl_TextEncoding eDest ) = 0;
virtual ScOrcusFilters* GetOrcusFilters() = 0;
diff --git a/sc/inc/global.hxx b/sc/inc/global.hxx
index 4db7beb76753..0698fbc11e34 100644
--- a/sc/inc/global.hxx
+++ b/sc/inc/global.hxx
@@ -660,8 +660,8 @@ SC_DLLPUBLIC static xub_StrLen FindUnquoted( const OUString& rString, s
*/
SC_DLLPUBLIC static const sal_Unicode* FindUnquoted( const sal_Unicode* pString, sal_Unicode cChar, sal_Unicode cQuote = '\'' );
- static CharSet GetCharsetValue( const OUString& rCharSet );
- static OUString GetCharsetString( CharSet eVal );
+ static rtl_TextEncoding GetCharsetValue( const OUString& rCharSet );
+ static OUString GetCharsetString( rtl_TextEncoding eVal );
/// a "ReadOnly" formatter for UNO/XML export
static SvNumberFormatter* GetEnglishFormatter();
diff --git a/sc/inc/lookupcache.hxx b/sc/inc/lookupcache.hxx
index 9bfc5417dbe7..0b6c53baec4f 100644
--- a/sc/inc/lookupcache.hxx
+++ b/sc/inc/lookupcache.hxx
@@ -24,7 +24,6 @@
#include "global.hxx"
#include "formula/token.hxx"
#include <svl/listener.hxx>
-#include <tools/string.hxx>
#include <boost/unordered_map.hpp>
diff --git a/sc/inc/patattr.hxx b/sc/inc/patattr.hxx
index 317f9aeef18e..cf09d54f5168 100644
--- a/sc/inc/patattr.hxx
+++ b/sc/inc/patattr.hxx
@@ -24,7 +24,6 @@
#include <svl/itemset.hxx>
#include <unotools/fontcvt.hxx>
#include <editeng/svxenum.hxx>
-#include <tools/string.hxx>
#include "scdllapi.h"
class Font;
diff --git a/sc/inc/pch/precompiled_sc.hxx b/sc/inc/pch/precompiled_sc.hxx
index 4ab57094246a..54b944fb6b03 100644
--- a/sc/inc/pch/precompiled_sc.hxx
+++ b/sc/inc/pch/precompiled_sc.hxx
@@ -937,7 +937,6 @@
#include <tools/shl.hxx>
#include <tools/solar.h>
#include <tools/stream.hxx>
-#include <tools/string.hxx>
#include <tools/tenccvt.hxx>
#include <tools/urlobj.hxx>
#include <tools/wintypes.hxx>
diff --git a/sc/inc/pch/precompiled_vbaobj.hxx b/sc/inc/pch/precompiled_vbaobj.hxx
index 67c8557494ef..c48f0150e2e3 100644
--- a/sc/inc/pch/precompiled_vbaobj.hxx
+++ b/sc/inc/pch/precompiled_vbaobj.hxx
@@ -314,7 +314,6 @@
#include <toolkit/awt/vclxwindow.hxx>
#include <toolkit/helper/vclunohelper.hxx>
#include <tools/diagnose_ex.h>
-#include <tools/string.hxx>
#include <tools/urlobj.hxx>
#include <unotools/eventcfg.hxx>
#include <vbahelper/helperdecl.hxx>
diff --git a/sc/inc/progress.hxx b/sc/inc/progress.hxx
index 4d3194f16f49..3c3c5f8c1bac 100644
--- a/sc/inc/progress.hxx
+++ b/sc/inc/progress.hxx
@@ -20,8 +20,8 @@
#ifndef SC_PROGRESS_HXX
#define SC_PROGRESS_HXX
+#include <rtl/ustring.hxx>
#include <sfx2/progress.hxx>
-#include <tools/string.hxx>
#include "scdllapi.h"
class ScDocument;
diff --git a/sc/inc/rangeutl.hxx b/sc/inc/rangeutl.hxx
index 26fe5890f37b..3b51c2690664 100644
--- a/sc/inc/rangeutl.hxx
+++ b/sc/inc/rangeutl.hxx
@@ -20,8 +20,6 @@
#ifndef SC_RANGEUTL_HXX
#define SC_RANGEUTL_HXX
-#include <tools/string.hxx>
-
#include "address.hxx"
#include "rangenam.hxx"
#include "dbdata.hxx"
diff --git a/sc/inc/scabstdlg.hxx b/sc/inc/scabstdlg.hxx
index fe3cf069183a..d5f6876eb193 100644
--- a/sc/inc/scabstdlg.hxx
+++ b/sc/inc/scabstdlg.hxx
@@ -21,7 +21,6 @@
#define _SC_ABSTDLG_HXX
#include <tools/solar.h>
-#include <tools/string.hxx>
#include <sfx2/sfxdlg.hxx>
#include <vcl/syswin.hxx>
#include <com/sun/star/uno/Sequence.hxx>
diff --git a/sc/inc/stringutil.hxx b/sc/inc/stringutil.hxx
index 5984da798094..08e5c1ed0314 100644
--- a/sc/inc/stringutil.hxx
+++ b/sc/inc/stringutil.hxx
@@ -20,10 +20,9 @@
#ifndef SC_STRINGUTIL_HXX
#define SC_STRINGUTIL_HXX
-#include "rtl/ustring.hxx"
-#include "tools/string.hxx"
+#include <rtl/ustring.hxx>
#include "scdllapi.h"
-#include "i18nlangtag/lang.h"
+#include <i18nlangtag/lang.h>
class SvNumberFormatter;
diff --git a/sc/inc/targuno.hxx b/sc/inc/targuno.hxx
index f18ee62e2fec..5c37de498be7 100644
--- a/sc/inc/targuno.hxx
+++ b/sc/inc/targuno.hxx
@@ -21,7 +21,6 @@
#define SC_TARGUNO_HXX
#include <svl/lstner.hxx>
-#include <tools/string.hxx>
#include <com/sun/star/document/XLinkTargetSupplier.hpp>
#include <com/sun/star/lang/XServiceName.hpp>
#include <com/sun/star/lang/XServiceInfo.hpp>
diff --git a/sc/inc/userlist.hxx b/sc/inc/userlist.hxx
index 0adb00519047..0cecf316bcfc 100644
--- a/sc/inc/userlist.hxx
+++ b/sc/inc/userlist.hxx
@@ -21,6 +21,7 @@
#define SC_USERLIST_HXX
#include <tools/stream.hxx>
+#include <tools/string.hxx>
#include "scdllapi.h"
#include <boost/ptr_container/ptr_vector.hpp>
diff --git a/sc/inc/zforauto.hxx b/sc/inc/zforauto.hxx
index c132a8af4410..dfadff3e6443 100644
--- a/sc/inc/zforauto.hxx
+++ b/sc/inc/zforauto.hxx
@@ -20,7 +20,7 @@
#ifndef _ZFORAUTO_HXX_
#define _ZFORAUTO_HXX_
-#include <tools/string.hxx>
+#include <rtl/ustring.hxx>
#include <i18nlangtag/lang.h>
@@ -37,8 +37,8 @@ public:
ScNumFormatAbbrev();
ScNumFormatAbbrev(const ScNumFormatAbbrev& aFormat);
ScNumFormatAbbrev(sal_uLong nFormat, SvNumberFormatter& rFormatter);
- void Load( SvStream& rStream, CharSet eByteStrSet ); // loading of the numberformats
- void Save( SvStream& rStream, CharSet eByteStrSet ) const; // saving of the numberformats
+ void Load( SvStream& rStream, rtl_TextEncoding eByteStrSet ); // loading of the numberformats
+ void Save( SvStream& rStream, rtl_TextEncoding eByteStrSet ) const; // saving of the numberformats
void PutFormatIndex(sal_uLong nFormat, SvNumberFormatter& rFormatter);
sal_uLong GetFormatIndex( SvNumberFormatter& rFormatter);
inline int operator==(const ScNumFormatAbbrev& rNumFormat) const
diff --git a/sc/source/core/data/documen8.cxx b/sc/source/core/data/documen8.cxx
index 980866d2ed9b..cb5162b5988c 100644
--- a/sc/source/core/data/documen8.cxx
+++ b/sc/source/core/data/documen8.cxx
@@ -20,7 +20,6 @@
#include "scitems.hxx"
#include <editeng/eeitem.hxx>
-#include <tools/string.hxx>
#include <tools/urlobj.hxx>
#include <editeng/editobj.hxx>
#include <editeng/editstat.hxx>
diff --git a/sc/source/core/inc/interpre.hxx b/sc/source/core/inc/interpre.hxx
index 99fa566620a7..bece096acd3d 100644
--- a/sc/source/core/inc/interpre.hxx
+++ b/sc/source/core/inc/interpre.hxx
@@ -23,6 +23,7 @@
#include <math.h>
#include <rtl/math.hxx>
#include <rtl/ustring.hxx>
+#include <tools/string.hxx>
#include "formula/errorcodes.hxx"
#include "formula/tokenarray.hxx"
#include "scdll.hxx"
diff --git a/sc/source/core/tool/zforauto.cxx b/sc/source/core/tool/zforauto.cxx
index 1655b2da8bd8..7dc049b0ef50 100644
--- a/sc/source/core/tool/zforauto.cxx
+++ b/sc/source/core/tool/zforauto.cxx
@@ -44,7 +44,7 @@ ScNumFormatAbbrev::ScNumFormatAbbrev(sal_uLong nFormat,
PutFormatIndex(nFormat, rFormatter);
}
-void ScNumFormatAbbrev::Load( SvStream& rStream, CharSet eByteStrSet )
+void ScNumFormatAbbrev::Load( SvStream& rStream, rtl_TextEncoding eByteStrSet )
{
sal_uInt16 nSysLang, nLang;
sFormatstring = rStream.ReadUniOrByteString( eByteStrSet );
@@ -55,7 +55,7 @@ void ScNumFormatAbbrev::Load( SvStream& rStream, CharSet eByteStrSet )
eSysLnge = Application::GetSettings().GetLanguageTag().getLanguageType();
}
-void ScNumFormatAbbrev::Save( SvStream& rStream, CharSet eByteStrSet ) const
+void ScNumFormatAbbrev::Save( SvStream& rStream, rtl_TextEncoding eByteStrSet ) const
{
rStream.WriteUniOrByteString( sFormatstring, eByteStrSet );
rStream << (sal_uInt16) eSysLnge << (sal_uInt16) eLnge;
diff --git a/sc/source/filter/dif/difexp.cxx b/sc/source/filter/dif/difexp.cxx
index fce42c27fc05..de90f1d1926c 100644
--- a/sc/source/filter/dif/difexp.cxx
+++ b/sc/source/filter/dif/difexp.cxx
@@ -34,7 +34,7 @@
#include "rtl/strbuf.hxx"
FltError ScFormatFilterPluginImpl::ScExportDif( SvStream& rStream, ScDocument* pDoc,
- const ScAddress& rOutPos, const CharSet eNach, sal_uInt32 nDifOption )
+ const ScAddress& rOutPos, const rtl_TextEncoding eNach, sal_uInt32 nDifOption )
{
SCCOL nEndCol;
SCROW nEndRow;
@@ -49,13 +49,13 @@ FltError ScFormatFilterPluginImpl::ScExportDif( SvStream& rStream, ScDocument* p
FltError ScFormatFilterPluginImpl::ScExportDif( SvStream& rOut, ScDocument* pDoc,
- const ScRange&rRange, const CharSet eCharSet, sal_uInt32 nDifOption )
+ const ScRange&rRange, const rtl_TextEncoding eCharSet, sal_uInt32 nDifOption )
{
OSL_ENSURE( rRange.aStart <= rRange.aEnd, "*ScExportDif(): Range not sorted!" );
OSL_ENSURE( rRange.aStart.Tab() == rRange.aEnd.Tab(),
"ScExportDif(): only one table please!" );
- const CharSet eStreamCharSet = rOut.GetStreamCharSet();
+ const rtl_TextEncoding eStreamCharSet = rOut.GetStreamCharSet();
if ( eStreamCharSet != eCharSet )
rOut.SetStreamCharSet( eCharSet );
diff --git a/sc/source/filter/dif/difimp.cxx b/sc/source/filter/dif/difimp.cxx
index fd9447d3d84b..53c1a6c8585a 100644
--- a/sc/source/filter/dif/difimp.cxx
+++ b/sc/source/filter/dif/difimp.cxx
@@ -21,7 +21,7 @@
#include <math.h>
#include <svl/zforlist.hxx>
-
+#include <tools/string.hxx>
#include "attrib.hxx"
#include "dif.hxx"
#include "docpool.hxx"
@@ -49,7 +49,7 @@ const sal_Unicode pKey1_0[] = { '1', ',', '0', 0 };
FltError ScFormatFilterPluginImpl::ScImportDif( SvStream& rIn, ScDocument* pDoc, const ScAddress& rInsPos,
- const CharSet eVon, sal_uInt32 nDifOption )
+ const rtl_TextEncoding eVon, sal_uInt32 nDifOption )
{
DifParser aDifParser( rIn, nDifOption, *pDoc, eVon );
@@ -234,7 +234,7 @@ FltError ScFormatFilterPluginImpl::ScImportDif( SvStream& rIn, ScDocument* pDoc,
}
-DifParser::DifParser( SvStream& rNewIn, const sal_uInt32 nOption, ScDocument& rDoc, CharSet e ) :
+DifParser::DifParser( SvStream& rNewIn, const sal_uInt32 nOption, ScDocument& rDoc, rtl_TextEncoding e ) :
rIn( rNewIn )
{
eCharSet = e;
diff --git a/sc/source/filter/excel/xistream.cxx b/sc/source/filter/excel/xistream.cxx
index c17cdfe43090..d4cb870ebf42 100644
--- a/sc/source/filter/excel/xistream.cxx
+++ b/sc/source/filter/excel/xistream.cxx
@@ -20,7 +20,7 @@
#include <comphelper/docpasswordhelper.hxx>
#include <comphelper/sequenceashashmap.hxx>
-
+#include <osl/thread.h>
#include "xistream.hxx"
#include "xlstring.hxx"
#include "xiroot.hxx"
diff --git a/sc/source/filter/inc/dif.hxx b/sc/source/filter/inc/dif.hxx
index 8ff00864252e..51daa73f6296 100644
--- a/sc/source/filter/inc/dif.hxx
+++ b/sc/source/filter/inc/dif.hxx
@@ -61,12 +61,12 @@ class ScPatternAttr;
class DifParser
{
public:
- OUString aData;
+ OUString aData;
double fVal;
- sal_uInt32 nVector;
- sal_uInt32 nVal;
- sal_uInt32 nNumFormat;
- CharSet eCharSet;
+ sal_uInt32 nVector;
+ sal_uInt32 nVal;
+ sal_uInt32 nNumFormat;
+ rtl_TextEncoding eCharSet;
private:
SvNumberFormatter* pNumFormatter;
SvStream& rIn;
@@ -80,7 +80,7 @@ private:
static inline sal_Bool IsEOD( const sal_Unicode* pRef );
static inline sal_Bool Is1_0( const sal_Unicode* pRef );
public:
- DifParser( SvStream&, const sal_uInt32 nOption, ScDocument&, CharSet );
+ DifParser( SvStream&, const sal_uInt32 nOption, ScDocument&, rtl_TextEncoding );
TOPIC GetNextTopic( void );
diff --git a/sc/source/filter/inc/eeparser.hxx b/sc/source/filter/inc/eeparser.hxx
index 7ef1583b19a5..ab7b209bd9a0 100644
--- a/sc/source/filter/inc/eeparser.hxx
+++ b/sc/source/filter/inc/eeparser.hxx
@@ -20,7 +20,6 @@
#ifndef SC_EEPARSER_HXX
#define SC_EEPARSER_HXX
-#include <tools/string.hxx>
#include <tools/gen.hxx>
#include <vcl/graph.hxx>
#include <svl/itemset.hxx>
diff --git a/sc/source/filter/inc/excscen.hxx b/sc/source/filter/inc/excscen.hxx
index 49a6e4240deb..8ec46e33a3f5 100644
--- a/sc/source/filter/inc/excscen.hxx
+++ b/sc/source/filter/inc/excscen.hxx
@@ -21,9 +21,8 @@
#define SC_EXCSCEN_HXX
#include <boost/ptr_container/ptr_vector.hpp>
-
+#include <rtl/ustring.hxx>
#include <tools/solar.h>
-#include <tools/string.hxx>
struct RootData;
class XclImpRoot;
diff --git a/sc/source/filter/inc/exp_op.hxx b/sc/source/filter/inc/exp_op.hxx
index 39b6f0ee0e65..1a6ce47f869b 100644
--- a/sc/source/filter/inc/exp_op.hxx
+++ b/sc/source/filter/inc/exp_op.hxx
@@ -38,9 +38,9 @@ protected:
SvStream& aOut; // Ausgabe-Stream
ScDocument* pD; // Dokument
- CharSet eZielChar; // Ziel-Zeichensatz
+ rtl_TextEncoding eZielChar; // Ziel-Zeichensatz
public:
- ExportTyp( SvStream& aStream, ScDocument* pDoc, CharSet eDest ):
+ ExportTyp( SvStream& aStream, ScDocument* pDoc, rtl_TextEncoding eDest ):
aOut( aStream )
{
eZielChar = eDest;
diff --git a/sc/source/filter/inc/ftools.hxx b/sc/source/filter/inc/ftools.hxx
index 23b205cfd8ad..b8d5cc783b3e 100644
--- a/sc/source/filter/inc/ftools.hxx
+++ b/sc/source/filter/inc/ftools.hxx
@@ -24,7 +24,6 @@
#include <map>
#include <limits>
#include <memory>
-#include <tools/string.hxx>
#include <sal/macros.h>
#include <boost/noncopyable.hpp>
#include <boost/shared_ptr.hpp>
@@ -280,7 +279,7 @@ public:
ScFormatFilterPluginImpl();
virtual ~ScFormatFilterPluginImpl();
// various import filters
- virtual FltError ScImportLotus123( SfxMedium&, ScDocument*, CharSet eSrc = RTL_TEXTENCODING_DONTKNOW );
+ virtual FltError ScImportLotus123( SfxMedium&, ScDocument*, rtl_TextEncoding eSrc = RTL_TEXTENCODING_DONTKNOW );
virtual FltError ScImportQuattroPro( SfxMedium &rMedium, ScDocument *pDoc );
virtual FltError ScImportExcel( SfxMedium&, ScDocument*, const EXCIMPFORMAT );
// eFormat == EIF_AUTO -> passender Filter wird automatisch verwendet
@@ -289,7 +288,7 @@ public:
// eFormat == EIF_BIFF_LE4 -> nur Nicht-Storage-Dateien _koennen_ zum Erfolg fuehren
virtual FltError ScImportStarCalc10( SvStream&, ScDocument* );
virtual FltError ScImportDif( SvStream&, ScDocument*, const ScAddress& rInsPos,
- const CharSet eSrc = RTL_TEXTENCODING_DONTKNOW, sal_uInt32 nDifOption = SC_DIFOPT_EXCEL );
+ const rtl_TextEncoding eSrc = RTL_TEXTENCODING_DONTKNOW, sal_uInt32 nDifOption = SC_DIFOPT_EXCEL );
virtual FltError ScImportRTF( SvStream&, const OUString& rBaseURL, ScDocument*, ScRange& rRange );
virtual FltError ScImportHTML( SvStream&, const OUString& rBaseURL, ScDocument*, ScRange& rRange,
double nOutputFactor = 1.0, bool bCalcWidthHeight = true,
@@ -300,14 +299,14 @@ public:
virtual OUString GetHTMLRangeNameList( ScDocument* pDoc, const OUString& rOrigName );
// various export filters
- virtual FltError ScExportExcel5( SfxMedium&, ScDocument*, ExportFormatExcel eFormat, CharSet eDest );
- virtual FltError ScExportDif( SvStream&, ScDocument*, const ScAddress& rOutPos, const CharSet eDest,
+ virtual FltError ScExportExcel5( SfxMedium&, ScDocument*, ExportFormatExcel eFormat, rtl_TextEncoding eDest );
+ virtual FltError ScExportDif( SvStream&, ScDocument*, const ScAddress& rOutPos, const rtl_TextEncoding eDest,
sal_uInt32 nDifOption = SC_DIFOPT_EXCEL );
- virtual FltError ScExportDif( SvStream&, ScDocument*, const ScRange& rRange, const CharSet eDest,
+ virtual FltError ScExportDif( SvStream&, ScDocument*, const ScRange& rRange, const rtl_TextEncoding eDest,
sal_uInt32 nDifOption = SC_DIFOPT_EXCEL );
- virtual FltError ScExportHTML( SvStream&, const OUString& rBaseURL, ScDocument*, const ScRange& rRange, const CharSet eDest, bool bAll,
+ virtual FltError ScExportHTML( SvStream&, const OUString& rBaseURL, ScDocument*, const ScRange& rRange, const rtl_TextEncoding eDest, bool bAll,
const OUString& rStreamPath, OUString& rNonConvertibleChars );
- virtual FltError ScExportRTF( SvStream&, ScDocument*, const ScRange& rRange, const CharSet eDest );
+ virtual FltError ScExportRTF( SvStream&, ScDocument*, const ScRange& rRange, const rtl_TextEncoding eDest );
virtual ScOrcusFilters* GetOrcusFilters();
};
diff --git a/sc/source/filter/inc/lotfntbf.hxx b/sc/source/filter/inc/lotfntbf.hxx
index a5430cfa5070..21fb9560f82c 100644
--- a/sc/source/filter/inc/lotfntbf.hxx
+++ b/sc/source/filter/inc/lotfntbf.hxx
@@ -21,7 +21,6 @@
#define SC_LOTFNTBF_HXX
#include <tools/solar.h>
-#include <tools/string.hxx>
#include "scitems.hxx"
#include <editeng/fontitem.hxx>
#include <editeng/fhgtitem.hxx>
diff --git a/sc/source/filter/inc/root.hxx b/sc/source/filter/inc/root.hxx
index 492a463e8994..8cb446d50ad1 100644
--- a/sc/source/filter/inc/root.hxx
+++ b/sc/source/filter/inc/root.hxx
@@ -92,7 +92,7 @@ struct LOTUS_ROOT
ScDocument* pDoc;
LotusRangeList* pRangeNames;
ScRangeName* pScRangeName;
- CharSet eCharsetQ;
+ rtl_TextEncoding eCharsetQ;
Lotus123Typ eFirstType;
Lotus123Typ eActType;
ScRange aActRange;
@@ -100,7 +100,7 @@ struct LOTUS_ROOT
LotusFontBuffer* pFontBuff;
LotAttrTable* pAttrTable;
- LOTUS_ROOT( ScDocument* pDocP, CharSet eQ );
+ LOTUS_ROOT( ScDocument* pDocP, rtl_TextEncoding eQ );
~LOTUS_ROOT();
};
diff --git a/sc/source/filter/inc/xestyle.hxx b/sc/source/filter/inc/xestyle.hxx
index d6950eed8a44..77061c8743dc 100644
--- a/sc/source/filter/inc/xestyle.hxx
+++ b/sc/source/filter/inc/xestyle.hxx
@@ -22,7 +22,6 @@
#include <map>
#include <tools/mempool.hxx>
-#include <tools/string.hxx>
#include <svl/zforlist.hxx>
#include <svl/nfkeytab.hxx>
#include <editeng/svxfont.hxx>
diff --git a/sc/source/filter/rtf/rtfexp.cxx b/sc/source/filter/rtf/rtfexp.cxx
index bb024e066293..e0efa750029d 100644
--- a/sc/source/filter/rtf/rtfexp.cxx
+++ b/sc/source/filter/rtf/rtfexp.cxx
@@ -45,7 +45,7 @@
//------------------------------------------------------------------
FltError ScFormatFilterPluginImpl::ScExportRTF( SvStream& rStrm, ScDocument* pDoc,
- const ScRange& rRange, const CharSet /*eNach*/ )
+ const ScRange& rRange, const rtl_TextEncoding /*eNach*/ )
{
ScRTFExport aEx( rStrm, pDoc, rRange );
return aEx.Write();
diff --git a/sc/source/ui/inc/AccessibleCsvControl.hxx b/sc/source/ui/inc/AccessibleCsvControl.hxx
index 822aec9236bf..ece01e9ed744 100644
--- a/sc/source/ui/inc/AccessibleCsvControl.hxx
+++ b/sc/source/ui/inc/AccessibleCsvControl.hxx
@@ -26,7 +26,6 @@
#include <com/sun/star/accessibility/XAccessibleTable.hpp>
#include <com/sun/star/accessibility/XAccessibleSelection.hpp>
#include <tools/gen.hxx>
-#include <tools/string.hxx>
#include <rtl/ustrbuf.hxx>
#include <cppuhelper/implbase1.hxx>
#include <cppuhelper/implbase2.hxx>
diff --git a/sc/source/ui/inc/asciiopt.hxx b/sc/source/ui/inc/asciiopt.hxx
index 3a40ae5c0734..9f1200eadf7e 100644
--- a/sc/source/ui/inc/asciiopt.hxx
+++ b/sc/source/ui/inc/asciiopt.hxx
@@ -22,7 +22,6 @@
#ifndef SC_ASCIIOPT_HXX
#define SC_ASCIIOPT_HXX
-#include <tools/string.hxx>
#include <vcl/dialog.hxx>
#include <vcl/button.hxx>
#include <vcl/fixed.hxx>
diff --git a/sc/source/ui/inc/autostyl.hxx b/sc/source/ui/inc/autostyl.hxx
index d4498662867c..d6db458abdfb 100644
--- a/sc/source/ui/inc/autostyl.hxx
+++ b/sc/source/ui/inc/autostyl.hxx
@@ -21,9 +21,7 @@
#define SC_AUTOSTYL_HXX
#include <boost/ptr_container/ptr_vector.hpp>
-
-#include <tools/string.hxx>
-
+#include <rtl/ustring.hxx>
#include <vcl/timer.hxx>
class ScDocShell;
diff --git a/sc/source/ui/inc/gridwin.hxx b/sc/source/ui/inc/gridwin.hxx
index b25f8497b5cf..8755da85bc0d 100644
--- a/sc/source/ui/inc/gridwin.hxx
+++ b/sc/source/ui/inc/gridwin.hxx
@@ -20,7 +20,6 @@
#ifndef SC_GRIDWIN_HXX
#define SC_GRIDWIN_HXX
-#include <tools/string.hxx>
#include <svtools/transfer.hxx>
#include "viewutil.hxx"
#include "viewdata.hxx"
diff --git a/sc/source/ui/inc/lnktrans.hxx b/sc/source/ui/inc/lnktrans.hxx
index 705a24542221..d9ccdebd06aa 100644
--- a/sc/source/ui/inc/lnktrans.hxx
+++ b/sc/source/ui/inc/lnktrans.hxx
@@ -21,7 +21,7 @@
#define SC_LNKTRANS_HXX
#include <svtools/transfer.hxx>
-#include <tools/string.hxx>
+#include <rtl/ustring.hxx>
class ScLinkTransferObj : public TransferableHelper
{
diff --git a/sc/source/ui/unoobj/pageuno.cxx b/sc/source/ui/unoobj/pageuno.cxx
index 2f36768e4aff..c4d485d81ff1 100644
--- a/sc/source/ui/unoobj/pageuno.cxx
+++ b/sc/source/ui/unoobj/pageuno.cxx
@@ -17,7 +17,7 @@
* the License at http://www.apache.org/licenses/LICENSE-2.0 .
*/
-#include <tools/string.hxx>
+#include <rtl/ustring.hxx>
#include "pageuno.hxx"
#include "shapeuno.hxx"
diff --git a/sc/source/ui/vba/vbaworksheet.cxx b/sc/source/ui/vba/vbaworksheet.cxx
index b31a0abe28e5..078c9e98fd1a 100644
--- a/sc/source/ui/vba/vbaworksheet.cxx
+++ b/sc/source/ui/vba/vbaworksheet.cxx
@@ -70,8 +70,6 @@
#include <com/sun/star/script/ModuleInfo.hpp>
#include <com/sun/star/script/ModuleType.hpp>
-#include <tools/string.hxx>
-
//zhangyun showdataform
#include <sfx2/sfxdlg.hxx>
#include "scabstdlg.hxx"
diff --git a/sc/source/ui/vba/vbaworksheets.cxx b/sc/source/ui/vba/vbaworksheets.cxx
index 4a3545c2b286..5d19147f9f64 100644
--- a/sc/source/ui/vba/vbaworksheets.cxx
+++ b/sc/source/ui/vba/vbaworksheets.cxx
@@ -38,7 +38,6 @@
#include <com/sun/star/beans/XPropertySet.hpp>
#include <ooo/vba/excel/XApplication.hpp>
-#include <tools/string.hxx>
#include "tabvwsh.hxx"
#include "vbaglobals.hxx"
diff --git a/sc/workben/result.hxx b/sc/workben/result.hxx
index 06cb8f917c10..835ae47c1c32 100644
--- a/sc/workben/result.hxx
+++ b/sc/workben/result.hxx
@@ -21,7 +21,7 @@
#define SC_RESULT_HXX
#include <vcl/timer.hxx>
-#include <tools/string.hxx>
+#include <rtl/ustring.hxx>
#include <boost/ptr_container/ptr_vector.hpp>
diff --git a/sc/source/ui/docshell/impex.cxx b/sc/source/ui/docshell/impex.cxx
index 85868ecf8708..d2c1d1e5b4a9 100644
--- a/sc/source/ui/docshell/impex.cxx
+++ b/sc/source/ui/docshell/impex.cxx
@@ -2083,7 +2083,7 @@ bool ScImportExport::Doc2Sylk( SvStream& rStrm )
bool ScImportExport::Doc2HTML( SvStream& rStrm, const OUString& rBaseURL )
{
// CharSet is ignored in ScExportHTML, read from Load/Save HTML options
ScFormatFilter::Get().ScExportHTML( rStrm, rBaseURL, pDoc, aRange, RTL_TEXTENCODING_DONTKNOW, bAll,
aStreamPath, aNonConvertibleChars );
return rStrm.GetError() == SVSTREAM_OK;
@@ -2091,7 +2091,7 @@ bool ScImportExport::Doc2HTML( SvStream& rStrm, const OUString& rBaseURL )
bool ScImportExport::Doc2RTF( SvStream& rStrm )
{
// CharSet is ignored in ScExportRTF
ScFormatFilter::Get().ScExportRTF( rStrm, pDoc, aRange, RTL_TEXTENCODING_DONTKNOW );
return rStrm.GetError() == SVSTREAM_OK;
}
@@ -2207,7 +2207,7 @@ class ScFormatFilterMissing : public ScFormatFilterPlugin {
OSL_FAIL("Missing file filters");
}
virtual ~ScFormatFilterMissing() {}
- virtual FltError ScImportLotus123( SfxMedium&, ScDocument*, CharSet ) RETURN_ERROR
+ virtual FltError ScImportLotus123( SfxMedium&, ScDocument*, rtl_TextEncoding ) RETURN_ERROR
virtual FltError ScImportQuattroPro( SfxMedium &, ScDocument * ) RETURN_ERROR
virtual FltError ScImportExcel( SfxMedium&, ScDocument*, const EXCIMPFORMAT ) RETURN_ERROR
virtual FltError ScImportStarCalc10( SvStream&, ScDocument* ) RETURN_ERROR
@@ -2220,12 +2220,12 @@ class ScFormatFilterMissing : public ScFormatFilterPlugin {
virtual ScEEAbsImport *CreateHTMLImport( ScDocument*, const OUString&, const ScRange&, bool ) { return NULL; }
virtual OUString GetHTMLRangeNameList( ScDocument*, const OUString& ) { return OUString(); }
- virtual FltError ScExportExcel5( SfxMedium&, ScDocument*, ExportFormatExcel, CharSet ) RETURN_ERROR
+ virtual FltError ScExportExcel5( SfxMedium&, ScDocument*, ExportFormatExcel, rtl_TextEncoding ) RETURN_ERROR
virtual FltError ScExportDif( SvStream&, ScDocument*, const ScAddress&, const CharSet, sal_uInt32 ) RETURN_ERROR
virtual FltError ScExportDif( SvStream&, ScDocument*, const ScRange&, const CharSet, sal_uInt32 ) RETURN_ERROR
virtual FltError ScExportHTML( SvStream&, const OUString&, ScDocument*, const ScRange&, const CharSet, bool,
const OUString&, OUString& ) RETURN_ERROR
- virtual FltError ScExportRTF( SvStream&, ScDocument*, const ScRange&, const CharSet ) RETURN_ERROR
+ virtual FltError ScExportRTF( SvStream&, ScDocument*, const ScRange&, const rtl_TextEncoding ) RETURN_ERROR
virtual ScOrcusFilters* GetOrcusFilters() { return NULL; }
};
@@ -2083,7 +2083,7 @@ bool ScImportExport::Doc2Sylk( SvStream& rStrm )
bool ScImportExport::Doc2HTML( SvStream& rStrm, const OUString& rBaseURL )
{
- // CharSet is ignored in ScExportHTML, read from Load/Save HTML options
+ // rtl_TextEncoding is ignored in ScExportHTML, read from Load/Save HTML options
ScFormatFilter::Get().ScExportHTML( rStrm, rBaseURL, pDoc, aRange, RTL_TEXTENCODING_DONTKNOW, bAll,
aStreamPath, aNonConvertibleChars );
@@ -2091,7 +2091,7 @@ bool ScImportExport::Doc2HTML( SvStream& rStrm, const OUString& rBaseURL )
bool ScImportExport::Doc2RTF( SvStream& rStrm )
{
- // CharSet is ignored in ScExportRTF
+ // rtl_TextEncoding is ignored in ScExportRTF
ScFormatFilter::Get().ScExportRTF( rStrm, pDoc, aRange, RTL_TEXTENCODING_DONTKNOW );
return rStrm.GetError() == SVSTREAM_OK;